--[[

Define German-language strings and chat message parsing funtion

need codes for special characters: ,,,,,,
  =#195##132# "..string.char(195)..string.char(132).."
  =#195##164# "..string.char(195)..string.char(164).."
  =#195##156# "..string.char(195)..string.char(156).."
  =#195##188# "..string.char(195)..string.char(188).."
  =#195##150# "..string.char(195)..string.char(150).."
  =#195##182# "..string.char(195)..string.char(182).."
  =#195##159# "..string.char(195)..string.char(159).."

]]--

_G.L = {};

L["PluginLoaded"] = " von K1R4D3L geladen";
L["PluginUnloaded"] = " von K1R4D3L entfernt";

L["CmdShow"] = "anzeigen";
L["CmdShowDesc"] = "Zeigt das KillTracker-Hauptfenster";
L["Usage"] = "Verwendung";

L["LoadFailure"] = "Fehler beim Laden der Datendatei. Daten werden nicht gespeichert, bis Datendatei repariert oder gel"..string.char(195)..string.char(182).."scht ist, und Zusatzmodul neu geladen wird.";

L["NoRows"] = "Keine Daten vorhanden."

L["ShowAllCharacters"] = "Alle Charaktere Anzeigen";

L["NumberSplitChar"] = ".";

L["DirectDamage"] = "Direkter Schaden";
L["TrapDamage"] = "Fallenschaden";
L["TheTrap"] = "Falle";

L["MobName"] = "Feind";
L["CharacterName"] = "Charakter";
L["LevelRange"] = "Stufen";
L["KillCount"] = "Get"..string.char(195)..string.char(182).."tet";

local function TrimArticles(name)
	name = string.gsub(name, "^[Dd]ie ", "");
	name = string.gsub(name, "^[Dd]em ", "");
	name = string.gsub(name, "^[Dd]er ", "");
	name = string.gsub(name, "^[Dd]en ", "");
	return name;
end

function L.Parse(line, channel)
  	-- find damage-dealing hits to mobs by character's pets, soldiers and devices
   if (channel == Turbine.ChatType.PlayerCombat) then
      -- only include hits to Morale
      local initiatorName, skillName, targetNameAndAmount = string.match(line, "^(.*) gelang ein .*Treffer mit \"(.*)\" gegen (.*) Punkte Schaden des Typs \".*\" auf Moral%.$");

      if (initiatorName ~= nil) then
         -- need to handle devices specially because kill messages don't match hit messages
         if (skillName == L.TrapDamage) then
            initiatorName = L.TheTrap;
         else
            initiatorName = TrimArticles(initiatorName);
         end

         -- skip character hits - don't need to use hit-matching for kills by the player directly
         --    if a player names a pet/soldier the same name as their character, this would miss (don't do that)
         if (initiatorName ~= player.name) then
            local targetName, amount = string.match(targetNameAndAmount, "^(.*) f\195\188r ([%d,]*)$");

            if (targetName ~= nil) then
			      targetName = TrimArticles(targetName);

			      amount = string.gsub(amount, ",", "") + 0;

               -- only include damage-dealing hits
               if (amount > 0) then
                  return 1, initiatorName, targetName;
               end
            end
         end
      end
   -- find damage-dealing reflects to mobs by character's pets and soldiers
   elseif (channel == Turbine.ChatType.EnemyCombat) then
      -- only include reflects to Morale
      local initiatorName, amount, dmgType, targetName = string.match(line, "^(.*) reflektierte ([%d,]*) Punkte Schaden des Typs (.*) auf Moral von (.*).$");
	
      if ((initiatorName ~= nil) and (dmgType ~= nil)) then
         initiatorName = TrimArticles(initiatorName);

         -- skip character reflects - don't need to use hit-matching for kills by the player directly
         --    if a player names a pet/soldier the same name as their character, this would miss (don't do that)
         if (initiatorName ~= player.name) then
            targetName = TrimArticles(targetName);

            amount = string.gsub(amount, ",", "") + 0;

            if (amount > 0) then
               return 1, initiatorName, targetName;
            end
         end
      end
   -- find mob kills by character and their pets, soldiers and devices
   elseif (channel == Turbine.ChatType.Death) then
      -- mob kills by the character directly
      local targetName = string.match(line, "^Mit m\195\164chtigem Hieb besiegt: (.*)%.$");

      if (targetName ~= nil) then
         targetName = TrimArticles(targetName);

         -- indicates that hit-matching and in-combat checking is not necessary
         local initiatorName = "$PLAYER$";
	
         return 9, initiatorName, targetName;
      end

      -- mob kills not by the character directly
      local initiatorName, targetName = string.match(line, "^Durch (.*) besiegt: (.*)%.$");

      if (initiatorName ~= nil) then
         initiatorName = TrimArticles(initiatorName);

         targetName = TrimArticles(targetName);
	
         return 9, initiatorName, targetName;
      end
   end
end

