--[[

Creates the main KillTracker master log viewer window, and provides a function
to refresh the table when the data is updated.

]]--

-- create and initialize the main KillTracker UI window
function _G.CreateMainWindow()
   -- show all characters' data or only the current character's?
   _G.showAllCharacters = false;
   
   _G.noDataDisplayed = true;

	_G.currentSort = "Enemy";	
	_G.currentSortOrder = "ASC";	

   -- the main window
	_G.statsWindow = ResizableWindow();

   statsWindow.minimumWidth = minWidth;
	statsWindow.minimumHeight = minHeight;

   statsWindow:SetSize(settings.width, settings.height);
	statsWindow:SetPosition(settings.leftPos, settings.topPos);
	statsWindow:SetText("KillTracker");
	statsWindow:SetZOrder(1);

   -- the main container for the kill log entries
   statsWindow.statsTable = Turbine.UI.ListBox();
   statsWindow.statsTable:SetParent(statsWindow.content);
	statsWindow.statsTable:SetPosition(15, 45);
	statsWindow.statsTable:SetSize(statsWindow.content:GetWidth() - 35, statsWindow.content:GetHeight() - 75);

   -- vertical scrollbar
   statsWindow.vscroll = Turbine.UI.Lotro.ScrollBar();
   statsWindow.vscroll:SetParent(statsWindow.content);
   statsWindow.vscroll:SetOrientation(Turbine.UI.Orientation.Vertical);
   statsWindow.vscroll:SetPosition(statsWindow.statsTable:GetLeft() + statsWindow.statsTable:GetWidth(), statsWindow.statsTable:GetTop());
   statsWindow.vscroll:SetSize(12, statsWindow.statsTable:GetHeight());
   statsWindow.statsTable:SetVerticalScrollBar(statsWindow.vscroll);

	-- add toggle checkbox to display all characters' data
   statsWindow.allCharactersToggle = Turbine.UI.Lotro.CheckBox();
	statsWindow.allCharactersToggle:SetParent(statsWindow.content);
	statsWindow.allCharactersToggle:SetSize(300, 20);
	statsWindow.allCharactersToggle:SetPosition(40, statsWindow:GetHeight() - 45);
	statsWindow.allCharactersToggle:SetCheckAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
	statsWindow.allCharactersToggle:SetChecked(false);
   statsWindow.allCharactersToggle:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
   statsWindow.allCharactersToggle:SetForeColor(Turbine.UI.Color(1,.9,.5));
   statsWindow.allCharactersToggle:SetOutlineColor(Turbine.UI.Color(0,0,0));
   statsWindow.allCharactersToggle:SetFontStyle(Turbine.UI.FontStyle.Outline);
	statsWindow.allCharactersToggle:SetMultiline(false);
	statsWindow.allCharactersToggle:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
	statsWindow.allCharactersToggle:SetText(" "..L.ShowAllCharacters);
	statsWindow.allCharactersToggle.Icon = Turbine.UI.Control();
	statsWindow.allCharactersToggle.Icon:SetParent(allCharactersToggle);
	statsWindow.allCharactersToggle.Icon:SetBlendMode(Turbine.UI.BlendMode.Overlay);
	statsWindow.allCharactersToggle.Icon:SetSize(32, 16);
	statsWindow.allCharactersToggle.Icon:SetPosition(0, 2);
	statsWindow.allCharactersToggle.Icon:SetBackground(0x41007e29);
	statsWindow.allCharactersToggle.Icon:SetMouseVisible(false);
	statsWindow.allCharactersToggle.CheckedChanged = function(sender, args)
		if sender:IsChecked() then
         showAllCharacters = true;
		else
         showAllCharacters = false;
         
			-- move the sort to the first column if hiding the sorted column
         if (currentSort == "Character") then
         	currentSort = "Enemy";
				currentSortOrder = "ASC";	
				statsWindow.headerRow[1]:SetText(L.MobName.." "..AscSortChar);
				statsWindow.headerRow[2]:SetText(L.CharacterName);
         end
		end

		RefreshKillsDisplay();

      statsWindow.content.Layout();
	end

   local tblWidth = statsWindow.statsTable:GetWidth();
      
   -- add column headers
   statsWindow.headerRow = {};

   local tmpRow = Turbine.UI.Control();
   tmpRow:SetParent(statsWindow.content);
   tmpRow:SetPosition(15, 25);
   tmpRow:SetSize(tblWidth, 20);
         
   -- target name header
   statsWindow.headerRow[1] = Turbine.UI.Label();
   statsWindow.headerRow[1]:SetParent(tmpRow);
   statsWindow.headerRow[1]:SetSize((tblWidth - 80 - 80 - 10), 20);
   statsWindow.headerRow[1]:SetPosition(5, 0);
   statsWindow.headerRow[1]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft); 
   statsWindow.headerRow[1]:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
   statsWindow.headerRow[1]:SetForeColor(Turbine.UI.Color(1,.9,.5));
   statsWindow.headerRow[1]:SetOutlineColor(Turbine.UI.Color(0,0,0));
   statsWindow.headerRow[1]:SetFontStyle(Turbine.UI.FontStyle.Outline);
	statsWindow.headerRow[1]:SetMultiline(false);
   statsWindow.headerRow[1]:SetText(L.MobName.." "..AscSortChar);
	statsWindow.headerRow[1].MouseClick = function(sender, args)
		if (not noDataDisplayed) then
			if (currentSort == "Enemy") then
				if (currentSortOrder == "ASC") then
					currentSortOrder = "DESC";
					statsWindow.headerRow[1]:SetText(L.MobName.." "..DescSortChar);
				else
					currentSortOrder = "ASC";
					statsWindow.headerRow[1]:SetText(L.MobName.." "..AscSortChar);
				end
			else
				currentSort = "Enemy";
				currentSortOrder = "ASC"; 
	
				statsWindow.headerRow[1]:SetText(L.MobName.." "..AscSortChar);
				statsWindow.headerRow[2]:SetText(L.CharacterName);
				statsWindow.headerRow[3]:SetText(L.LevelRange);
				statsWindow.headerRow[4]:SetText(L.KillCount);
			end
					
	      RefreshKillsDisplay();
	   end
	end
   -- character name(server ID) header
   statsWindow.headerRow[2] = Turbine.UI.Label();
   statsWindow.headerRow[2]:SetParent(tmpRow);
   statsWindow.headerRow[2]:SetSize(0, 20);
   statsWindow.headerRow[2]:SetPosition(((tblWidth - 80 - 80 - 10) * 0.7) + 5 - 20, 0);
   statsWindow.headerRow[2]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft); 
   statsWindow.headerRow[2]:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
   statsWindow.headerRow[2]:SetForeColor(Turbine.UI.Color(1,.9,.5));
   statsWindow.headerRow[2]:SetOutlineColor(Turbine.UI.Color(0,0,0));
   statsWindow.headerRow[2]:SetFontStyle(Turbine.UI.FontStyle.Outline);
	statsWindow.headerRow[2]:SetMultiline(false);
   statsWindow.headerRow[2]:SetText(L.CharacterName);
	statsWindow.headerRow[2].MouseClick = function(sender, args)
		if (not noDataDisplayed) then
			if (currentSort == "Character") then
				if (currentSortOrder == "ASC") then
					currentSortOrder = "DESC";
					statsWindow.headerRow[2]:SetText(L.CharacterName.." "..DescSortChar);
				else
					currentSortOrder = "ASC";
					statsWindow.headerRow[2]:SetText(L.CharacterName.." "..AscSortChar);
				end
			else
				currentSort = "Character";
				currentSortOrder = "ASC"; 
	
				statsWindow.headerRow[1]:SetText(L.MobName);
				statsWindow.headerRow[2]:SetText(L.CharacterName.." "..AscSortChar);
				statsWindow.headerRow[3]:SetText(L.LevelRange);
				statsWindow.headerRow[4]:SetText(L.KillCount);
			end
					
	      RefreshKillsDisplay();
		end
	end
   -- kill level range header
   statsWindow.headerRow[3] = Turbine.UI.Label();
   statsWindow.headerRow[3]:SetParent(tmpRow);
   statsWindow.headerRow[3]:SetSize(80, 20);
   statsWindow.headerRow[3]:SetPosition((tblWidth - 80 - 80 - 5), 0);
   statsWindow.headerRow[3]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter); 
   statsWindow.headerRow[3]:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
   statsWindow.headerRow[3]:SetForeColor(Turbine.UI.Color(1,.9,.5));
   statsWindow.headerRow[3]:SetOutlineColor(Turbine.UI.Color(0,0,0));
   statsWindow.headerRow[3]:SetFontStyle(Turbine.UI.FontStyle.Outline);
	statsWindow.headerRow[3]:SetMultiline(false);
   statsWindow.headerRow[3]:SetText(L.LevelRange);
	statsWindow.headerRow[3].MouseClick = function(sender, args)
		if (not noDataDisplayed) then
			if (currentSort == "Level") then
				if (currentSortOrder == "ASC") then
					currentSortOrder = "DESC";
					statsWindow.headerRow[3]:SetText(L.LevelRange.." "..DescSortChar);
				else
					currentSortOrder = "ASC";
					statsWindow.headerRow[3]:SetText(L.LevelRange.." "..AscSortChar);
				end
			else
				currentSort = "Level";
				currentSortOrder = "ASC"; 
	
				statsWindow.headerRow[1]:SetText(L.MobName);
				statsWindow.headerRow[2]:SetText(L.CharacterName);
				statsWindow.headerRow[3]:SetText(L.LevelRange.." "..AscSortChar);
				statsWindow.headerRow[4]:SetText(L.KillCount);
			end
					
	      RefreshKillsDisplay();
		end
	end
   -- kill count header
   statsWindow.headerRow[4] = Turbine.UI.Label();
   statsWindow.headerRow[4]:SetParent(tmpRow);
   statsWindow.headerRow[4]:SetSize(80, 20);
   statsWindow.headerRow[4]:SetPosition((tblWidth - 80 - 5), 0);
   statsWindow.headerRow[4]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight); 
   statsWindow.headerRow[4]:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
   statsWindow.headerRow[4]:SetForeColor(Turbine.UI.Color(1,.9,.5));
   statsWindow.headerRow[4]:SetOutlineColor(Turbine.UI.Color(0,0,0));
   statsWindow.headerRow[4]:SetFontStyle(Turbine.UI.FontStyle.Outline);
	statsWindow.headerRow[4]:SetMultiline(false);
   statsWindow.headerRow[4]:SetText(L.KillCount);
	statsWindow.headerRow[4].MouseClick = function(sender, args)
		if (not noDataDisplayed) then
			if (currentSort == "Kills") then
				if (currentSortOrder == "ASC") then
					currentSortOrder = "DESC";
					statsWindow.headerRow[4]:SetText(L.KillCount.." "..DescSortChar);
				else
					currentSortOrder = "ASC";
					statsWindow.headerRow[4]:SetText(L.KillCount.." "..AscSortChar);
				end
			else
				currentSort = "Kills";
				currentSortOrder = "ASC"; 
	
				statsWindow.headerRow[1]:SetText(L.MobName);
				statsWindow.headerRow[2]:SetText(L.CharacterName);
				statsWindow.headerRow[3]:SetText(L.LevelRange);
				statsWindow.headerRow[4]:SetText(L.KillCount.." "..AscSortChar);
			end
					
	      RefreshKillsDisplay();
		end
	end

	-- message to display when there is no data, create hidden
   local tmpRow = Turbine.UI.Control();
   tmpRow:SetParent(statsWindow.statsTable);
   tmpRow:SetSize(statsWindow.statsTable:GetWidth(), 0);
	statsWindow.noRowsMessage = Turbine.UI.Label();
	statsWindow.noRowsMessage:SetParent(tmpRow);
	statsWindow.noRowsMessage:SetSize(200, 20);
	statsWindow.noRowsMessage:SetPosition(5, 0);
	statsWindow.noRowsMessage:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft); 
	statsWindow.noRowsMessage:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	statsWindow.noRowsMessage:SetMultiline(false);
	statsWindow.noRowsMessage:SetText(L.NoRows);
	statsWindow.statsTable:AddItem(tmpRow);
   
   -- define a function to save new window size/position settings when moved/resized
   statsWindow.SaveState = function()
      -- only save the settings if the window is visible
      if (statsWindow:IsVisible()) then
         settings.leftPos, settings.topPos = statsWindow:GetPosition();
         settings.width, settings.height = statsWindow:GetSize();
   
         -- save settings to Character-level file
         SaveSettings();
      end
   end

   -- table to hold individual kill log UI element rows
   statsWindow.killRows = {};
   
   -- refresh layout of window after resize
   statsWindow.content.Layout = function()
      statsWindow.statsTable:SetSize(statsWindow.content:GetWidth() - 35, statsWindow.content:GetHeight() - 75);

      local newWidth = statsWindow.statsTable:GetWidth();

      statsWindow.vscroll:SetLeft(statsWindow.statsTable:GetLeft() + newWidth);
      statsWindow.vscroll:SetHeight(statsWindow.statsTable:GetHeight());

      statsWindow.allCharactersToggle:SetTop(statsWindow:GetHeight() - 45);

      local tmpRow = statsWindow.headerRow[1]:GetParent();
      tmpRow:SetWidth(newWidth);

      if (showAllCharacters) then
         statsWindow.headerRow[1]:SetWidth(((newWidth - 80 - 80 - 10) * 0.7) - 5 - 20);
         statsWindow.headerRow[2]:SetWidth(((newWidth - 80 - 80 - 10) * 0.3) - 5 + 20);
         statsWindow.headerRow[2]:SetLeft(((newWidth - 80 - 80 - 10) * 0.7) + 5 - 20);
      else
         statsWindow.headerRow[1]:SetWidth(newWidth - 80 - 80 - 10);
         statsWindow.headerRow[2]:SetWidth(0);
      end

      statsWindow.headerRow[3]:SetLeft(newWidth - 80 - 80 - 5);
      statsWindow.headerRow[4]:SetLeft(newWidth - 80 - 5);
   
      for i = 1, #statsWindow.killRows do
         local tmpRow = statsWindow.killRows[i][1]:GetParent();
         tmpRow:SetWidth(newWidth);
         
         if (showAllCharacters) then
            statsWindow.killRows[i][1]:SetWidth(((newWidth - 80 - 80 - 10) * 0.7) - 5 - 20);
            statsWindow.killRows[i][2]:SetWidth(((newWidth - 80 - 80 - 10) * 0.3) - 5 + 20);
            statsWindow.killRows[i][2]:SetLeft(((newWidth - 80 - 80 - 10) * 0.7) + 5 - 20);
         else
            statsWindow.killRows[i][1]:SetWidth(newWidth - 80 - 80 - 10);
            statsWindow.killRows[i][2]:SetWidth(0);
         end

         statsWindow.killRows[i][3]:SetLeft(newWidth - 80 - 80 - 5);
         statsWindow.killRows[i][4]:SetLeft(newWidth - 80 - 5);
      end
   end

	-- create icon to quickly open main KillTracker UI window
	_G.minWindow = MinimizedWindow();
	minWindow:SetPosition(settings.iconLeft, settings.iconTop);
   
   -- define a function to save new icon position settings when moved
   minWindow.SaveState = function()
      -- only save the settings if the window is visible
      if (minWindow:IsVisible()) then
         settings.iconLeft, settings.iconTop = minWindow:GetPosition();
   
         -- save settings to Character-level file
         SaveSettings();
      end
   end
   
   -- redisplay quick icon when main window closed
   statsWindow.Close = function()
		K1R4D3L.KillTracker.UI.ResizableWindow.Close(statsWindow);
		
		minWindow:SetVisible(true);
	end
end

function sortByEnemyASC(arg1, arg2)
	if (arg1[1] < arg2[1]) then
		return(true);
	elseif ((arg1[1] == arg2[1]) and (arg1[5] < arg2[5])) then
		return(true);
	end
end

function sortByEnemyDESC(arg1, arg2)
	if (arg1[1] > arg2[1]) then
		return(true);
	elseif ((arg1[1] == arg2[1]) and (arg1[5] < arg2[5])) then
		return(true);
	end
end

function sortByCharacterASC(arg1, arg2)
	if (arg1[5] < arg2[5]) then
		return(true);
	elseif ((arg1[5] == arg2[5]) and (arg1[1] < arg2[1])) then
		return(true);
	end
end

function sortByCharacterDESC(arg1, arg2)
	if (arg1[5] > arg2[5]) then
		return(true);
	elseif ((arg1[5] == arg2[5]) and (arg1[1] < arg2[1])) then
		return(true);
	end
end

function sortByLevelASC(arg1, arg2)
	if (arg1[3] < arg2[3]) then
		return(true);
	elseif ((arg1[3] == arg2[3]) and (arg1[1] < arg2[1])) then
		return(true);
	elseif ((arg1[3] == arg2[3]) and (arg1[1] == arg2[1]) and (arg1[5] < arg2[5])) then
		return(true);
	end
end

function sortByLevelDESC(arg1, arg2)
	if (arg1[3] > arg2[3]) then
		return(true);
	elseif ((arg1[3] == arg2[3]) and (arg1[1] < arg2[1])) then
		return(true);
	elseif ((arg1[3] == arg2[3]) and (arg1[1] == arg2[1]) and (arg1[5] < arg2[5])) then
		return(true);
	end
end

function sortByKillsASC(arg1, arg2)
	if (arg1[2] < arg2[2]) then
		return(true);
	elseif ((arg1[2] == arg2[2]) and (arg1[1] < arg2[1])) then
		return(true);
	elseif ((arg1[2] == arg2[2]) and (arg1[1] == arg2[1]) and (arg1[5] < arg2[5])) then
		return(true);
	end
end

function sortByKillsDESC(arg1, arg2)
	if (arg1[2] > arg2[2]) then
		return(true);
	elseif ((arg1[2] == arg2[2]) and (arg1[1] < arg2[1])) then
		return(true);
	elseif ((arg1[2] == arg2[2]) and (arg1[1] == arg2[1]) and (arg1[5] < arg2[5])) then
		return(true);
	end
end

-- refresh the results table in the window 
function _G.RefreshKillsDisplay()
   local rowsDisplayed = 0;

   -- only do this if the window is visible and there are results to display
   if (statsWindow:IsVisible() and (#killsTable > 0)) then
	   -- sort the table alpha by target name if there is more than one record
	   if (#killsTable > 1) then
	   	if (currentSort == "Character") then
	   		if (currentSortOrder == "ASC") then
	      		table.sort(killsTable, sortByCharacterASC);
	      	else
	      		table.sort(killsTable, sortByCharacterDESC);
	      	end
	      elseif (currentSort == "Level") then
	   		if (currentSortOrder == "ASC") then
	      		table.sort(killsTable, sortByLevelASC);
	      	else
	      		table.sort(killsTable, sortByLevelDESC);
	      	end
	      elseif (currentSort == "Kills") then
	   		if (currentSortOrder == "ASC") then
	      		table.sort(killsTable, sortByKillsASC);
	      	else
	      		table.sort(killsTable, sortByKillsDESC);
	      	end
	      else
	   		if (currentSortOrder == "ASC") then
	      		table.sort(killsTable, sortByEnemyASC);
	      	else
	      		table.sort(killsTable, sortByEnemyDESC);
	      	end
			end
	   end
	
	   local tblWidth = statsWindow.statsTable:GetWidth();
	
	   -- loop through master kills log
	   for i = 1, #killsTable do
	      -- only display kills for this character unless showAllCharacters is set
	      if ((killsTable[i][5] == player.uniqueName) or (showAllCharacters)) then
	         -- increment row count for positioning
	         rowsDisplayed = rowsDisplayed + 1;
	      
	         -- update existing UI element row if it exists
	         if (#statsWindow.killRows >= rowsDisplayed) then
         		local tmpRow = statsWindow.killRows[rowsDisplayed][1]:GetParent();
         		tmpRow:SetHeight(22);

	            statsWindow.killRows[rowsDisplayed][1]:SetText(killsTable[i][1]);
	            statsWindow.killRows[rowsDisplayed][2]:SetText(killsTable[i][5]);
	            statsWindow.killRows[rowsDisplayed][3]:SetText(FormatNumber(killsTable[i][3]).."-"..FormatNumber(killsTable[i][4]));
	            statsWindow.killRows[rowsDisplayed][4]:SetText(FormatNumber(killsTable[i][2]));
	         -- add a new row
	         else
	            statsWindow.killRows[rowsDisplayed] = {};
	         
	            local tmpRow = Turbine.UI.Control();
	            tmpRow:SetParent(statsWindow.statsTable);
	            tmpRow:SetSize(tblWidth, 22);
	            tmpRow:SetBackColorBlendMode(Turbine.UI.BlendMode.AlphaBlend);
	            -- even row highlighting
	            if (rowsDisplayed % 2 == 0) then
	               tmpRow:SetBackColor(Turbine.UI.Color(0.1, 1, 1, 1));
	            end
	         
	            -- target name
	            statsWindow.killRows[rowsDisplayed][1] = Turbine.UI.Label();
	            statsWindow.killRows[rowsDisplayed][1]:SetParent(tmpRow);
	            if (showAllCharacters) then
	               statsWindow.killRows[rowsDisplayed][1]:SetSize(((tblWidth - 80 - 80 - 10) * 0.7) - 5 - 20, 20);
	            else
	               statsWindow.killRows[rowsDisplayed][1]:SetSize((tblWidth - 80 - 80 - 10), 20);
	            end
	            statsWindow.killRows[rowsDisplayed][1]:SetPosition(5, 1);
	            statsWindow.killRows[rowsDisplayed][1]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft); 
	            statsWindow.killRows[rowsDisplayed][1]:SetBackColorBlendMode(Turbine.UI.BlendMode.AlphaBlend);
	            statsWindow.killRows[rowsDisplayed][1]:SetFont(Turbine.UI.Lotro.Font.Verdana12);
					statsWindow.killRows[rowsDisplayed][1]:SetMultiline(false);
	            statsWindow.killRows[rowsDisplayed][1]:SetText(killsTable[i][1]);
	            -- character name(server ID)
	            statsWindow.killRows[rowsDisplayed][2] = Turbine.UI.Label();
	            statsWindow.killRows[rowsDisplayed][2]:SetParent(tmpRow);
	            statsWindow.killRows[rowsDisplayed][2]:SetSize(((tblWidth - 80 - 80 - 10) * 0.3) - 5 + 20, 20);
	            statsWindow.killRows[rowsDisplayed][2]:SetPosition(((tblWidth - 80 - 80 - 10) * 0.7) + 5 - 20, 1);
	            statsWindow.killRows[rowsDisplayed][2]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft); 
	            statsWindow.killRows[rowsDisplayed][2]:SetBackColorBlendMode(Turbine.UI.BlendMode.AlphaBlend);
	            statsWindow.killRows[rowsDisplayed][2]:SetFont(Turbine.UI.Lotro.Font.Verdana12);
					statsWindow.killRows[rowsDisplayed][2]:SetMultiline(false);
	            statsWindow.killRows[rowsDisplayed][2]:SetText(killsTable[i][5]);
	            if (not showAllCharacters) then
	               statsWindow.killRows[rowsDisplayed][2]:SetSize(0, 20);
	            end
	            -- kill level range
	            statsWindow.killRows[rowsDisplayed][3] = Turbine.UI.Label();
	            statsWindow.killRows[rowsDisplayed][3]:SetParent(tmpRow);
	            statsWindow.killRows[rowsDisplayed][3]:SetSize(80, 20);
	            statsWindow.killRows[rowsDisplayed][3]:SetPosition((tblWidth - 80 - 80 - 5), 1);
	            statsWindow.killRows[rowsDisplayed][3]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter); 
	            statsWindow.killRows[rowsDisplayed][3]:SetBackColorBlendMode(Turbine.UI.BlendMode.AlphaBlend);
	            statsWindow.killRows[rowsDisplayed][3]:SetFont(Turbine.UI.Lotro.Font.Verdana12);
					statsWindow.killRows[rowsDisplayed][3]:SetMultiline(false);
	            statsWindow.killRows[rowsDisplayed][3]:SetText(FormatNumber(killsTable[i][3]).."-"..FormatNumber(killsTable[i][4]));
	            -- kill count
	            statsWindow.killRows[rowsDisplayed][4] = Turbine.UI.Label();
	            statsWindow.killRows[rowsDisplayed][4]:SetParent(tmpRow);
	            statsWindow.killRows[rowsDisplayed][4]:SetSize(80, 20);
	            statsWindow.killRows[rowsDisplayed][4]:SetPosition((tblWidth - 80 - 5), 1);
	            statsWindow.killRows[rowsDisplayed][4]:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight); 
	            statsWindow.killRows[rowsDisplayed][4]:SetBackColorBlendMode(Turbine.UI.BlendMode.AlphaBlend);
	            statsWindow.killRows[rowsDisplayed][4]:SetFont(Turbine.UI.Lotro.Font.Verdana12);
					statsWindow.killRows[rowsDisplayed][4]:SetMultiline(false);
	            statsWindow.killRows[rowsDisplayed][4]:SetText(FormatNumber(killsTable[i][2]));
	         
	            statsWindow.statsTable:AddItem(tmpRow);
	         end
	      end
	   end
	end

	-- hide rows that no longer have data, setting height to 0 for the scrollbar
	if (#statsWindow.killRows > rowsDisplayed) then 
		for i = rowsDisplayed + 1, #statsWindow.killRows do
         local tmpRow = statsWindow.killRows[i][1]:GetParent();
         tmpRow:SetHeight(0);
		end
	end

   -- hide/show the No Data message, setting height to 0 for the scrollbar
	local tmpRow = statsWindow.noRowsMessage:GetParent();

   if (rowsDisplayed == 0) then
		noDataDisplayed = true;
      tmpRow:SetHeight(20);
	else
		noDataDisplayed = false;
		tmpRow:SetHeight(0);
   end
end
